.. PageBot Cocoa documentation master file, created by
   sphinx-quickstart on Thu Jul 18 10:07:01 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PageBot Cocoa's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README.md


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
